@@ -353,7 +353,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.actions = struct(save=save, save_format=save_format, saveAs=saveAs, open=open, close=close,
                               resetAll=resetAll,
                               lineColor=color1, create=create, createRegion=createRegion, createScale=createScale,delete=delete, edit=edit,
-                              copy=copy, detect=detect, excel=excel, trainModel=trainModel,
+                              copy=copy, detect=detect, excel=excel, #trainModel=trainModel,
                               createMode=createMode, editMode=editMode, advancedMode=advancedMode,
                               shapeLineColor=shapeLineColor, shapeFillColor=shapeFillColor,
                               zoom=zoom, zoomIn=zoomIn, zoomOut=zoomOut, zoomOrg=zoomOrg,
@@ -424,7 +424,7 @@ class MainWindow(QMainWindow, WindowMixin):
 
         self.menus.file.aboutToShow.connect(self.updateFileMenu)
 
-        addActions(self.menus.stoma, (create, createRegion, detect, createScale, excel, trainModel,close))
+        addActions(self.menus.stoma, (create, createRegion, detect, createScale, excel,close))#, trainModel
 
         # Custom context menu for the canvas widget:
         addActions(self.canvas.menus[0], self.actions.beginnerContext)
@@ -435,7 +435,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.tools = self.toolbar('Tools')
 
         self.actions.beginner = (
-            open, opendir, openNextImg, openPrevImg,None, save,  detect,excel,trainModel,None,create, createRegion, createScale, delete)
+            open, opendir, openNextImg, openPrevImg,None, save,  detect,excel,None,create, createRegion, createScale, delete)#,trainModel
 
         self.actions.advanced = ()
 
@@ -598,7 +598,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.actions.createScale.setEnabled(True)
         self.actions.detect.setEnabled(True)
         self.actions.excel.setEnabled(True)
-        self.actions.trainModel.setEnabled(True)
+        #self.actions.trainModel.setEnabled(True)
 
     def toggleActions(self, value=True):
         """Enable/Disable widgets which depend on an opened image."""
@@ -673,7 +673,7 @@ class MainWindow(QMainWindow, WindowMixin):
 
     def createShapeRegion(self):
         assert self.beginner()
-        self.text = 'superficie'
+        self.text = 'surface'
         self.canvas.setEditing(False)
         self.actions.create.setEnabled(False)
         self.actions.createRegion.setEnabled(False)
@@ -1454,12 +1454,15 @@ class MainWindow(QMainWindow, WindowMixin):
         ui = Ui_Dialog()
         ui.setupUi(Dialog)
         x = Dialog.exec_()
-        #print(ui.es)
         if ui.genera:
-            generaExcel(os.path.dirname(ustr(self.filePath)), ui.esca, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
-            self.setWindowIcon(QtGui.QIcon("resources/icons/excel.png"))
-            QMessageBox.about(self, "Information", "Excel finished")
-            self.setWindowIcon(newIcon("app"))
+            try:
+                generaExcel(os.path.dirname(ustr(self.filePath)), ui.esca, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
+                self.setWindowIcon(QtGui.QIcon("resources/icons/excel.png"))
+                QMessageBox.about(self, "Information", "Excel finished")
+                self.setWindowIcon(newIcon("app"))
+            except:
+                QMessageBox.about(self, "Information", "Introduce the value of the scale")
+                self.generarExcel()
         # QMessageBox msgBox
         # msgBox.setText("Excel finished")
         # msgBox.exec()
