@@ -95,10 +95,10 @@ def generaExcel(carpeta, es, pixeles, unidad, nEsto,medAltura, medAnchura, desvA
         # print(filename.text)  # primer elto del que obtenemos el título de nuestro video
         # ws.write(i, 0, nomImagen.text.split('\\')[len(nomImagen.text.split('/'))-1])
         nom =os.path.split(nomImagen.text)
-        nom2 = nom[1].split(sep='.')
-        ws.write(i, 0, nom2[0]+extImages)
-        ws2.write(i, 0, nom2[0]+extImages)
-        ws3.write(i, 0, nom2[0]+extImages)
+        (nom2, ext2) = os.path.splitext(nom[1])
+        ws.write(i, 0, nom2+extImages)
+        ws2.write(i, 0, nom2+extImages)
+        ws3.write(i, 0, nom2+extImages)
         # Calculamos el número de estomas por imagen
         objetos = filename.findall("object")
         surface = 0
